<?php
/*
Plugin Name: Daily Upload Dir
Plugin URI: http://wordpress.org/extend/plugins/daily-upload-dir/
Description: Organizes your uploads into year, month and day-based folders. Uses the post's timestamp when creating dirs.
Version: 1.0
Author: Ulf Benjaminsson

Remember to turn on "Organize my uploads into month- and year-based folders" in Miscellaneous Options.

Thanks to futurix for some code and idea: http://wordpress.org/support/topic/119565
The rest of the code is basically lifted straight from WP's default wp_upload_dir().
*/

add_filter('upload_dir', 'ulfben_get_upload_dir'); 


/* 
This method effectively replaces "wp_upload_dir()", and does a few things differently:
	1. it'll create a daily subdirectory if you've checked "Organize my uploads into month- and year-based folders" in Miscellaneous Options.
	2. it'll use the current post's date instead of the current date. (eg: adding files to a post from 2003-03-23 will put the files in /wp_uploads/2003/03/23)
*/
function ulfben_get_upload_dir() 
{			
	$siteurl = get_option('siteurl');
	
	//prepend ABSPATH to $dir and $siteurl to $url if they're not already there
	$path = str_replace(ABSPATH, '', trim(get_option('upload_path')));
	$dir = ABSPATH . $path;
	$url = trailingslashit($siteurl) . $path;		
	if ( $dir == ABSPATH ) { $dir = ABSPATH . 'wp-content/uploads'; 	} //the option was empty
	
	if ( defined('UPLOADS') ) {
		$dir = ABSPATH . UPLOADS;
		$url = trailingslashit($siteurl) . UPLOADS;
	}				
			
	if (get_option('uploads_use_yearmonth_folders'))
	{
		global $post_id;						
		$time = current_time('timestamp'); 
					
		if (isset($post_id))
		{
			$mypost = get_post($post_id);	
			if (is_object($mypost) && $mypost->post_date != "0000-00-00 00:00:00") //only use the post_date if it has been defined (ie. published or manually altered)
			{ 
				$time = strtotime($mypost->post_date); 	//using the post's timestamp
			} 		
		}
		
		$y = date("Y", $time);
		$m = date("m", $time);
		$d = date("d", $time); 				
		
		$subdir = "/$y/$m/$d";
		
		$dir = $dir . $subdir;
		$url = $url . $subdir;			
	}					
	
	if ( ! wp_mkdir_p( $dir ) ) {
		$message = sprintf(__('Unable to create directory %s. Is its parent directory writable by the server?'), $dir);
		return array('error' => $message);
	}
	
	$uploads = array('path' => $dir, 'url' => $url, 'error' => false);		
	return $uploads;
}	

?>